@@ -15,42 +15,55 @@
 
 """Agent action implementations"""
 
+import logging
+
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils
 import six
 
-from openstackclient.common import command
-from openstackclient.common import utils
+from openstackclient.i18n import _
+
+
+LOG = logging.getLogger(__name__)
 
 
 class CreateAgent(command.ShowOne):
-    """Create compute agent command"""
+    """Create compute agent"""
 
     def get_parser(self, prog_name):
         parser = super(CreateAgent, self).get_parser(prog_name)
         parser.add_argument(
             "os",
             metavar="<os>",
-            help="Type of OS")
+            help=_("Type of OS")
+        )
         parser.add_argument(
             "architecture",
             metavar="<architecture>",
-            help="Type of architecture")
+            help=_("Type of architecture")
+        )
         parser.add_argument(
             "version",
             metavar="<version>",
-            help="Version")
+            help=_("Version")
+        )
         parser.add_argument(
             "url",
             metavar="<url>",
-            help="URL")
+            help=_("URL")
+        )
         parser.add_argument(
             "md5hash",
             metavar="<md5hash>",
-            help="MD5 hash")
+            help=_("MD5 hash")
+        )
         parser.add_argument(
             "hypervisor",
             metavar="<hypervisor>",
-            help="Type of hypervisor",
-            default="xen")
+            default="xen",
+            help=_("Type of hypervisor")
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -68,30 +81,46 @@ class CreateAgent(command.ShowOne):
 
 
 class DeleteAgent(command.Command):
-    """Delete compute agent command"""
+    """Delete compute agent(s)"""
 
     def get_parser(self, prog_name):
         parser = super(DeleteAgent, self).get_parser(prog_name)
         parser.add_argument(
             "id",
             metavar="<id>",
-            help="ID of agent to delete")
+            nargs='+',
+            help=_("ID of agent(s) to delete")
+        )
         return parser
 
     def take_action(self, parsed_args):
         compute_client = self.app.client_manager.compute
-        compute_client.agents.delete(parsed_args.id)
+        result = 0
+        for id in parsed_args.id:
+            try:
+                compute_client.agents.delete(id)
+            except Exception as e:
+                result += 1
+                LOG.error(_("Failed to delete agent with ID '%(id)s': %(e)s"),
+                          {'id': id, 'e': e})
+
+        if result > 0:
+            total = len(parsed_args.id)
+            msg = (_("%(result)s of %(total)s agents failed "
+                     "to delete.") % {'result': result, 'total': total})
+            raise exceptions.CommandError(msg)
 
 
 class ListAgent(command.Lister):
-    """List compute agent command"""
+    """List compute agents"""
 
     def get_parser(self, prog_name):
         parser = super(ListAgent, self).get_parser(prog_name)
         parser.add_argument(
             "--hypervisor",
             metavar="<hypervisor>",
-            help="Type of hypervisor")
+            help=_("Type of hypervisor")
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -113,34 +142,58 @@ class ListAgent(command.Lister):
 
 
 class SetAgent(command.Command):
-    """Set compute agent command"""
+    """Set compute agent properties"""
 
     def get_parser(self, prog_name):
         parser = super(SetAgent, self).get_parser(prog_name)
         parser.add_argument(
             "id",
             metavar="<id>",
-            help="ID of the agent")
+            help=_("ID of the agent")
+        )
         parser.add_argument(
-            "version",
+            "--agent-version",
+            dest="version",
             metavar="<version>",
-            help="Version of the agent")
+            help=_("Version of the agent")
+        )
         parser.add_argument(
-            "url",
+            "--url",
             metavar="<url>",
-            help="URL")
+            help=_("URL of the agent")
+        )
         parser.add_argument(
-            "md5hash",
+            "--md5hash",
             metavar="<md5hash>",
-            help="MD5 hash")
+            help=_("MD5 hash of the agent")
+        )
         return parser
 
     def take_action(self, parsed_args):
         compute_client = self.app.client_manager.compute
+        data = compute_client.agents.list(hypervisor=None)
+        agent = {}
+
+        for s in data:
+            if s.agent_id == int(parsed_args.id):
+                agent['version'] = s.version
+                agent['url'] = s.url
+                agent['md5hash'] = s.md5hash
+        if agent == {}:
+            msg = _("No agent with a ID of '%(id)s' exists.")
+            raise exceptions.CommandError(msg % parsed_args.id)
+
+        if parsed_args.version:
+            agent['version'] = parsed_args.version
+        if parsed_args.url:
+            agent['url'] = parsed_args.url
+        if parsed_args.md5hash:
+            agent['md5hash'] = parsed_args.md5hash
+
         args = (
             parsed_args.id,
-            parsed_args.version,
-            parsed_args.url,
-            parsed_args.md5hash
+            agent['version'],
+            agent['url'],
+            agent['md5hash'],
         )
         compute_client.agents.update(*args)
