@@ -15,10 +15,12 @@
 
 """Identity v3 Token action implementations"""
 
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils
 import six
 
-from openstackclient.common import command
-from openstackclient.common import utils
+from openstackclient.i18n import _
 from openstackclient.identity import common
 
 
@@ -30,17 +32,17 @@ class AuthorizeRequestToken(command.ShowOne):
         parser.add_argument(
             '--request-key',
             metavar='<request-key>',
-            help='Request token to authorize (ID only) (required)',
-            required=True
+            required=True,
+            help=_('Request token to authorize (ID only) (required)'),
         )
         parser.add_argument(
             '--role',
             metavar='<role>',
             action='append',
             default=[],
-            help='Roles to authorize (name or ID) '
-                 '(repeat to set multiple values) (required)',
-            required=True
+            required=True,
+            help=_('Roles to authorize (name or ID) '
+                   '(repeat option to set multiple values, required)'),
         )
         return parser
 
@@ -71,31 +73,31 @@ class CreateAccessToken(command.ShowOne):
         parser.add_argument(
             '--consumer-key',
             metavar='<consumer-key>',
-            help='Consumer key (required)',
+            help=_('Consumer key (required)'),
             required=True
         )
         parser.add_argument(
             '--consumer-secret',
             metavar='<consumer-secret>',
-            help='Consumer secret (required)',
+            help=_('Consumer secret (required)'),
             required=True
         )
         parser.add_argument(
             '--request-key',
             metavar='<request-key>',
-            help='Request token to exchange for access token (required)',
+            help=_('Request token to exchange for access token (required)'),
             required=True
         )
         parser.add_argument(
             '--request-secret',
             metavar='<request-secret>',
-            help='Secret associated with <request-key> (required)',
+            help=_('Secret associated with <request-key> (required)'),
             required=True
         )
         parser.add_argument(
             '--verifier',
             metavar='<verifier>',
-            help='Verifier associated with <request-key> (required)',
+            help=_('Verifier associated with <request-key> (required)'),
             required=True
         )
         return parser
@@ -117,26 +119,26 @@ class CreateRequestToken(command.ShowOne):
         parser.add_argument(
             '--consumer-key',
             metavar='<consumer-key>',
-            help='Consumer key (required)',
+            help=_('Consumer key (required)'),
             required=True
         )
         parser.add_argument(
             '--consumer-secret',
             metavar='<consumer-secret>',
-            help='Consumer secret (required)',
+            help=_('Consumer secret (required)'),
             required=True
         )
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help='Project that consumer wants to access (name or ID)'
-                 ' (required)',
+            help=_('Project that consumer wants to access (name or ID)'
+                   ' (required)'),
             required=True
         )
         parser.add_argument(
             '--domain',
             metavar='<domain>',
-            help='Domain owning <project> (name or ID)',
+            help=_('Domain owning <project> (name or ID)'),
         )
         return parser
 
@@ -172,10 +174,23 @@ class IssueToken(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        token = self.app.client_manager.auth_ref.service_catalog.get_token()
-        if 'tenant_id' in token:
-            token['project_id'] = token.pop('tenant_id')
-        return zip(*sorted(six.iteritems(token)))
+        auth_ref = self.app.client_manager.auth_ref
+        if not auth_ref:
+            raise exceptions.AuthorizationFailure(
+                _("Only an authorized user may issue a new token."))
+
+        data = {}
+        if auth_ref.auth_token:
+            data['id'] = auth_ref.auth_token
+        if auth_ref.expires:
+            data['expires'] = auth_ref.expires
+        if auth_ref.project_id:
+            data['project_id'] = auth_ref.project_id
+        if auth_ref.user_id:
+            data['user_id'] = auth_ref.user_id
+        if auth_ref.domain_id:
+            data['domain_id'] = auth_ref.domain_id
+        return zip(*sorted(six.iteritems(data)))
 
 
 class RevokeToken(command.Command):
@@ -186,7 +201,7 @@ class RevokeToken(command.Command):
         parser.add_argument(
             'token',
             metavar='<token>',
-            help='Token to be deleted',
+            help=_('Token to be deleted'),
         )
         return parser
 
