@@ -15,14 +15,20 @@
 
 """Volume v1 Type action implementations"""
 
+import logging
+
+from osc_lib.cli import parseractions
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils
 import six
 
-from openstackclient.common import command
-from openstackclient.common import parseractions
-from openstackclient.common import utils
 from openstackclient.i18n import _
 
 
+LOG = logging.getLogger(__name__)
+
+
 class CreateVolumeType(command.ShowOne):
     """Create new volume type"""
 
@@ -56,22 +62,39 @@ class CreateVolumeType(command.ShowOne):
 
 
 class DeleteVolumeType(command.Command):
-    """Delete volume type"""
+    """Delete volume type(s)"""
 
     def get_parser(self, prog_name):
         parser = super(DeleteVolumeType, self).get_parser(prog_name)
         parser.add_argument(
-            'volume_type',
+            'volume_types',
             metavar='<volume-type>',
-            help=_('Volume type to delete (name or ID)'),
+            nargs='+',
+            help=_('Volume type(s) to delete (name or ID)'),
         )
         return parser
 
     def take_action(self, parsed_args):
         volume_client = self.app.client_manager.volume
-        volume_type_id = utils.find_resource(
-            volume_client.volume_types, parsed_args.volume_type).id
-        volume_client.volume_types.delete(volume_type_id)
+        result = 0
+
+        for volume_type in parsed_args.volume_types:
+            try:
+                vol_type = utils.find_resource(volume_client.volume_types,
+                                               volume_type)
+
+                volume_client.volume_types.delete(vol_type)
+            except Exception as e:
+                result += 1
+                LOG.error(_("Failed to delete volume type with "
+                            "name or ID '%(volume_type)s': %(e)s")
+                          % {'volume_type': volume_type, 'e': e})
+
+        if result > 0:
+            total = len(parsed_args.volume_types)
+            msg = (_("%(result)s of %(total)s volume types failed "
+                   "to delete.") % {'result': result, 'total': total})
+            raise exceptions.CommandError(msg)
 
 
 class ListVolumeType(command.Lister):
